@@ -5,6 +5,8 @@
       LOGICAL   LFCATR
       INTEGER   ITPATX
 
+      CALL SGIGET('IFCIDX',IFCIDX)
+
       CALL SWQFCC(LFCATR)
       IF(.NOT.LFCATR) THEN
         CALL MSGDMP('M','SGTNXV','FULL COLOR MODE IS NOT SUPPORTED.')
@@ -25,7 +27,8 @@
       CALL SWSTCL(ICOLOR)
       CALL SWSLCL(ICOLOR)
 
-      ITPATX=999*1000+MOD(ITPAT,1000)
+
+      ITPATXI=IFCIDX*1000+MOD(ITPAT,1000)
       CALL SZTNOP(ITPATX)
       CALL SZTNZV(N,VPX,VPY)
       CALL SZTNCL
