@@ -20,6 +20,7 @@
 
       ITPATZ=ITPAT
       CALL SGIGET('IBGCLI',IBGCLI)
+      CALL SGIGET('IFCIDX',IFCIDX)
 
       IF (LFRST) THEN
 
@@ -77,6 +78,7 @@
               CALL CHNGI(CMSG,'##',LC,'(I2)')
               CALL MSGDMP('W','SWGTON',CMSG)
             END IF
+          ELSE IF(LC.EQ.999)THEN
           ELSE
             CMSG='COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.'
             CALL CHNGI(CMSG,'##',LC,'(I2)')
@@ -90,11 +92,13 @@
       IF (ITCLIY.EQ.IBGCLI) THEN
         ITPATY=ITPNMY
       ELSE
-        IF (ITCLIY.EQ.0) ITCLIY=1
+        IF (ITCLIY.EQ.0) THEN
+          ITCLIY=1
+        END IF
         ITPATY=ITPNMY+ITCLIY*1000
       END IF
 
-      IF (ITPNMY .EQ. 999) THEN
+      IF (ITPNMY .EQ. IFCIDX) THEN
         LHARD=.TRUE.
       END IF
       CALL SZSTMD(LHARD)
